@@ -28,14 +28,15 @@ mixpanelGetFunnel <- function(
   class(res) <- c("funnel", "list")
   
   if("customEvents" %in% names(account)) {
-    ## Update all funnels.
     for(iFunnel in 1:length(res)) {
       funnel <- res[[iFunnel]]
       
-      for(i in which(!is.na(funnel$custom_event)))
-        funnel$event[i] <- funnel$goal[i] <- customEventNameDecode(account, funnel$custom_event_id[i]) 
+      if("custom_event" %in% colnames(funnel)) {
+        for(i in which(!is.na(funnel$custom_event)))
+          funnel$event[i] <- funnel$goal[i] <- customEventNameDecode(account, funnel$custom_event_id[i]) 
       
-      res[[iFunnel]] <- funnel
+        res[[iFunnel]] <- funnel
+      }
     }
   }
   
